@@ -2,10 +2,12 @@ from deskbar.Handler import *
 from deskbar.Match import *
 from time import sleep
 import gtk
+from deskbar.defs import VERSION
 
 HANDLERS = {
 	"AsyncDebugHandler" : {
 		"name": "Debug (Async)",
+		"version": VERSION,
 	}
 }
 
@@ -32,7 +34,7 @@ class AsyncDebugHandler (AsyncHandler):
 	def __init__ (self):
 		AsyncHandler.__init__ (self, "stock_script")
 		
-	def query (self, qstring, max):
+	def query (self, qstring):
 		
 		for i in range (NUM_QUERIES):
 			sleep (QUERY_TIME)
