@@ -3,6 +3,7 @@ import gnomevfs, gtk
 
 from gettext import gettext as _
 import xml.dom.minidom, urllib
+from deskbar.defs import VERSION
 
 GCONF_DELICIOUS_USER  = deskbar.GCONF_DIR+"/desklicious/user"
 
@@ -12,15 +13,16 @@ QUERY_DELAY = 1
 def _check_requirements():
 	#We need user and password
 	if not deskbar.GCONF_CLIENT.get_string(GCONF_DELICIOUS_USER):
-		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, _("You need to configure your deli.icio.us account."), _on_config_account)
+		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, _("You need to configure your del.icio.us account."), _on_config_account)
 	else:
-		return (deskbar.Handler.HANDLER_IS_CONFIGURABLE, _("You can modify your deli.icio.us account."), _on_config_account)
+		return (deskbar.Handler.HANDLER_IS_CONFIGURABLE, _("You can modify your del.icio.us account."), _on_config_account)
 
 HANDLERS = {
 	"DeliciousHandler" : {
 		"name": _("del.icio.us Bookmarks"),
 		"description": _("Search your del.icio.us bookmarks by tag name"),
-		"requirements" : _check_requirements
+		"requirements" : _check_requirements,
+		"version": VERSION,
 	}
 }
 
@@ -32,7 +34,7 @@ def _on_config_account(dialog):
 	
 	table = gtk.Table(rows=2, columns=2)
 	
-	table.attach(gtk.Label(_("Enter your deli.icio.us username below")), 0, 2, 0, 1)
+	table.attach(gtk.Label(_("Enter your del.icio.us username below")), 0, 2, 0, 1)
 
 	user_entry = gtk.Entry()
 	t = deskbar.GCONF_CLIENT.get_string(GCONF_DELICIOUS_USER)
