@@ -3,11 +3,13 @@ from gettext import gettext as _
 import gnomevfs
 import deskbar.Handler
 import re
+from deskbar.defs import VERSION
 
 HANDLERS = {
 	"EmailAddressHandler" : {
 		"name": _("Mail"),
 		"description": _("Send mail by typing a complete e-mail address"),
+		"version": VERSION,
 	}
 }
 
@@ -34,7 +36,7 @@ class EmailAddressHandler(deskbar.Handler.Handler):
 	def __init__(self):
 		deskbar.Handler.Handler.__init__(self, "stock_mail")
 		
-	def query(self, query, max):
+	def query(self, query):
 		if REGEX.match(query) != None:
 			return [EmailAddressMatch(self, name=query)]
 		else:
